import random

class UserAgentGen:
    def __init__(self):
        self.browsers = {
            "Chrome": {
                "user_agent": "Mozilla/5.0 ({os}; {arch}) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/{version} Safari/537.36",
                "versions": [
                    "113.0.5672.63", "114.0.5735.90", "115.0.5790.98", "116.0.5845.97",
                    "117.0.5938.92", "118.0.6040.20", "119.0.6136.21"
                ]
            },
            "Firefox": {
                "user_agent": "Mozilla/5.0 ({os}; {arch}) Gecko/20100101 Firefox/{version}",
                "versions": [
                    "114.0", "115.0", "116.0", "117.0", "118.0"
                ]
            },
            "Edge": {
                "user_agent": "Mozilla/5.0 ({os}; {arch}) AppleWebKit/537.36 (KHTML, like Gecko) Edg/{version}",
                "versions": [
                    "113.0.1998.58", "114.0.1823.67", "115.0.1920.77", "116.0.2053.23"
                ]
            },
            "Safari": {
                "user_agent": "Mozilla/5.0 ({os}; {arch}) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/{version} Safari/605.1.15",
                "versions": [
                    "15.6.1", "16.0", "16.1", "16.2", "16.3"
                ]
            },
            "Opera": {
                "user_agent": "Mozilla/5.0 ({os}; {arch}) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/{chrome_version} Safari/537.36 OPR/{version}",
                "versions": [
                    "99.0.4788.77", "100.0.4815.27", "101.0.4951.64", "102.0.5071.40"
                ]
            },
            "Internet Explorer": {
                "user_agent": "Mozilla/5.0 ({os}; {arch}) Trident/{trident_version} like Gecko IE/{version}",
                "versions": [
                    "11.0", "10.0", "9.0", "8.0", "7.0"
                ]
            },
        }

        self.operating_systems = {
            "Windows": [
                "Windows NT 10.0; Win64; x64", "Windows NT 10.0; Win32", "Windows NT 11.0; Win64; x64",
                "Windows NT 10.0; ARM", "Windows NT 10.0; WOW64"
            ],
            "Macintosh": [
                "Macintosh; Intel Mac OS X 10_15_7", "Macintosh; Intel Mac OS X 11_0", "Macintosh; Apple Mac OS X 12_3",
                "Macintosh; Apple Mac OS X 13_0"
            ],
            "Linux": [
                "X11; Ubuntu; Linux x86_64", "X11; Debian; Linux x86_64", "X11; Fedora; Linux x86_64",
                "X11; Arch Linux; Linux x86_64", "X11; openSUSE; Linux x86_64"
            ],
            "Android": [
                "Android 10; Mobile", "Android 11; Mobile", "Android 12; Mobile", "Android 13; Mobile",
                "Android 14; Mobile"
            ],
            "iOS": [
                "iPhone; CPU iPhone OS 15_0 like Mac OS X", "iPhone; CPU iPhone OS 16_0 like Mac OS X",
                "iPad; CPU OS 15_0 like Mac OS X", "iPad; CPU OS 16_0 like Mac OS X"
            ]
        }

        self.architectures = {
            "Windows": ["Win64; x64", "Win32", "WOW64", "ARM"],
            "Macintosh": ["Intel Mac OS X", "Apple Mac OS X"],
            "Linux": ["x86_64", "x86"],
            "Android": ["Mobile"],
            "iOS": ["iPhone", "iPad"]
        }

        self.trident_versions = ["7.0"]

    def random_os_and_arch(self):
        os_name = random.choice(list(self.operating_systems.keys()))
        architecture = random.choice(self.architectures[os_name])
        return os_name, architecture

    def generate_user_agent(self, browser):
        os_name, architecture = self.random_os_and_arch()
        version = random.choice(self.browsers[browser]["versions"])
        if browser == "Opera":
            chrome_version = version
            user_agent = self.browsers[browser]["user_agent"].format(
                os=os_name,
                arch=architecture,
                version=version,
                chrome_version=chrome_version
            )
        elif browser == "Internet Explorer":
            trident_version = random.choice(self.trident_versions)
            user_agent = self.browsers[browser]["user_agent"].format(
                os=os_name,
                arch=architecture,
                version=version,
                trident_version=trident_version
            )
        else:
            user_agent = self.browsers[browser]["user_agent"].format(
                os=os_name,
                arch=architecture,
                version=version
            )
        return user_agent

    def chrome(self):
        """Return a random, but realistc user-agent for Chrome"""
        return self.generate_user_agent("Chrome")

    def firefox(self):
        """Return a random, but realistc user-agent for Firefox"""
        return self.generate_user_agent("Firefox")

    def edge(self):
        """Return a random, but realistc user-agent for Microsoft Edge"""
        return self.generate_user_agent("Edge")

    def safari(self):
        """Return a random, but realistc user-agent for Safari"""
        return self.generate_user_agent("Safari")

    def opera(self):
        """Return a random, but realistc user-agent for Opera"""
        return self.generate_user_agent("Opera")

    def internet_explorer(self):
        """Return a random, but realistc user-agent for Internet Explorer"""
        return self.generate_user_agent("Internet Explorer")



from .cords import RealTimeCords
from .email_gen import MailGen
from .password_gen import PasswordGen
from .random_user_agent import UserAgentGen
from .humanbehavior import HumanBehavior

__ALL__ = [RealTimeCords, MailGen, PasswordGen, UserAgentGen, HumanBehavior]


import random
import string

class PasswordGen():
    def __init__(self):
        pass
    
    def gen_password(self):
        special_char = "?!£$%&();"
        rand_number = str(random.randint(1, 999))
        password = "".join(random.choices(string.ascii_letters + string.ascii_lowercase + string.ascii_uppercase + special_char + rand_number , k=18))
        return password


import pyautogui
import time

class RealTimeCords:
    def __init__(self):
        pass
    def print_mouse_position():
        """Description: 
        - sends the cords on which you are moving the mice on the screen Args: Nobody Return: X and y coordinates
        
        Return:
        - x and y coordinates
        """
        try:
            while True:
                x, y = pyautogui.position()
                print(f"X: {x}, Y: {y}", end='\r') 
                time.sleep(0.01)  
        except KeyboardInterrupt:
            print("\nRegistration Interrupted!")



import random
import string
import time

class HumanBehavior:
    def type_text_slowly(self, page, selector, text: str, error_probability: float = 0.25, delay_range: tuple = (0.1, 0.3)) -> None:
        """
        Realistically mimics a user's input by typing text slowly, introducing random errors and pauses.

        This method simulates human-like typing behavior by inserting random errors and delays
        between keystrokes.

        Args:
            page: The page context where the input should be typed (e.g., context.new_page()).
            selector: The input selector for the text field where the text will be entered.
            text (str): The text to write in the specified selector.
            error_probability (float, optional): The probability of introducing an error for each lowercase character. Defaults to 0.25 (25%).
            delay_range (tuple, optional): A tuple specifying the minimum and maximum delay (in seconds) between keystrokes. Defaults to (0.1, 0.3).

        Returns:
            None: This method does not return a value. It performs actions directly on the specified page.
    
        Raises:
            ValueError: If delay_range is not a tuple with two values (min, max).
    """
        if not isinstance(delay_range, tuple) or len(delay_range) != 2:
            raise ValueError("delay_range must be a tuple with two values (min, max).")
        for char in text:
            if random.random() < error_probability and char.islower():
                wrong_char = random.choice(string.ascii_lowercase)
                page.type(selector, wrong_char)
                time.sleep(random.uniform(delay_range[0], delay_range[1]))
                page.keyboard.press("Backspace")
                time.sleep(random.uniform(delay_range[0], delay_range[1]))
            page.type(selector, char)
            time.sleep(random.uniform(delay_range[0], delay_range[1]))




import random

class MailGen:
    def __init__(self):
        pass
    
    def gen_mail(self):
        """
        Generate a random email address using various first names, last names, and domains.

        Returns:
            str: A randomly generated email address.
        """
        nomi = [
    "Alessandro", "Giovanni", "Lorenzo", "Mattia", "Gabriele",
    "Riccardo", "Nicola", "Leonardo", "Andrea", "Francesco",
    "Davide", "Simone", "Marco", "Stefano", "Giulio",
    "Luca", "Matteo", "Daniele", "Alessio", "Angelo",
    "Carlo", "Vincenzo", "Federico", "Emanuele", "Giuseppe",
    "Antonio", "Salvatore", "Pietro", "Roberto", "Filippo",
    "Diego", "Cristiano", "Raffaele", "Sebastiano", "Fabio",
    "Elia", "Leonardo", "Tommaso", "Aldo", "Giordano",
    "Alberto", "Umberto", "Giorgio", "Salvatore", "Nicolò",
    "Gianluca", "Piero", "Ernesto", "Martino", "Riccardo",
    "Lucio", "Gianni", "Ruggero", "Giulio", "Tiziano",
    "Dario", "Rinaldo", "Renato", "Alfredo", "Ettore",
    "Edoardo", "Vittorio", "Maurizio", "Claudio", "Sergio",
    "Nerino", "Emilio", "Alberto", "Benedetto", "Orazio",
    "Leone", "Luciano", "Adriano", "Graziano", "Giuseppe",
    "Carmine", "Agostino", "Bartolomeo", "Beppe", "Domenico",
    "Ferdinando", "Guido", "Ignazio", "Lazzaro", "Michele",
    "Onofrio", "Quinto", "Silvano", "Umberto", "Virgilio",
    "Zeno", "Sisto", "Ascanio", "Corrado", "Clemente",
    "Dante", "Sandro", "Nazzareno", "Teodoro", "Rocco",
    "Marcello", "Alessandro", "Claudio", "Giorgio", "Ivo",
    "Livio", "Mauro", "Osvaldo", "Rinaldo", "Savino",
    "Taddeo", "Ulisse", "Zefiro"
        ]

        cognomi = [
    "Rossi", "Ferrari", "Russo", "Colombo", "Ricci",
    "Marino", "Greco", "Bruno", "Gallo", "Conti",
    "Daniele", "Rizzo", "Lombardi", "Moretti", "Barbieri",
    "Fabbri", "Fontana", "Cattaneo", "Giordano",
    "Costa", "Romano", "Sartori", "Valenti", "Riva",
    "Sorrentino", "Palmieri", "Mancini", "Martini", "Vitali",
    "Testa", "Miele", "Ruggeri", "Farina",
    "Carbone", "Mariani", "Pugliese", "Ferri", "Caputo",
    "Rinaldi", "Giorgi", "Pereira", "Barbato", "Silvestri",
    "Corsi", "D'Angelo", "Cipriani", "Ventura", "Fusco",
    "Battaglia", "Cavalli", "Marta","Savino",
    "Mancuso", "Pagano", "Giuliani", "Schiavone",
    "Fiore", "Giustino", "Palmieri", "Luciano",
    "Marchetti", "Lucarelli", "Bianchi", "Gatti", "Longo",
    "Ricciardi", "Bianco", "Rossi", "Calabrese",
    "Monti", "Rinaldi", "Battisti", "Serra", "Tedesco",
    "Montalto", "Bertolini", "Alessi", "Ruggeri",
    "Fiorentino", "Fioravanti", "Palumbo", "Salvatori", "Martelli",
    "Giuliano", "Palmieri", "Rocca", "Serafini", "Giannini",
    "Petrucci", "Lombardo", "Sgro", "Giorgetti", "Ventura"
        ]
    
        domains = [
    "gmail.com",
    "libero.it",
    "hotmail.com",
    "yahoo.it",
    "alice.it",
    "outlook.com",
        ]   
    
        rnd_number = random.randint(1, 999)
        rnd_name = random.choice(nomi)
        rnd_cognome = random.choice(cognomi)
        rnd_domain = random.choice(domains)
    
        formats = (
        f"{rnd_name}.{rnd_cognome}{rnd_number}@{rnd_domain}",
        f"{rnd_name}.{rnd_cognome}@{rnd_domain}",
        f"{rnd_name}_{rnd_cognome}{rnd_number}@{rnd_domain}",
        f"{rnd_name}_{rnd_cognome}@{rnd_domain}",
        f"{rnd_name}.{rnd_cognome}_{rnd_number}@{rnd_domain}",
        f"{rnd_name}_{rnd_cognome}.{rnd_number}@{rnd_domain}"
        )
        return random.choice(formats)



from setuptools import setup, find_packages
 
setup(
    name='Ciola',
    version='1.0.5',
    author='Lapsus',
    author_email='',
    description='A personal library',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    packages=find_packages(),
    install_requires=[
        'pyautogui',
    ],
    classifiers=[
        'Programming Language :: Python :: 3.10',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.10',
)
